pub fn verify(data: &[u8], algorithm: &str, expected: &str) -> boolExpand description
Verify data against an expected hex digest using the named algorithm.
Supported algorithms: sha256, sha512, md5, crc32.
Returns true on match, false on mismatch or unknown algorithm.